@@ -76,7 +76,7 @@ use LWP::UserAgent;
 
 package WWW::Shopify;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use WWW::Shopify::Exception;
 use WWW::Shopify::Field;
@@ -104,14 +104,13 @@ Creates a new shop, without using the actual API, uses automated form submission
 sub new { 
 	my ($package, $shop_url, $email, $password) = @_;
 	die new WWW::Shopify::Exception("Can't create a shop without a shop url.") unless $shop_url;
-	my $ua = LWP::UserAgent->new( ssl_opts => {'SSL_version' => 'TLSv12' } );
+	my $ua = LWP::UserAgent->new( ($^O eq' linux' ? (ssl_opts => {'SSL_version' => 'TLSv12' }) : ()) );
 	$ua->cookie_jar({ });
 	$ua->timeout(30);	
-	$ua->agent("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.22 (KHTML, like Gecko) Chrome/25.0.1364.5 Safari/537.22");
+	$ua->agent("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/48.0.2564.116 Safari/537.36");
 	$package = "WWW::Shopify::Login" if $package eq "WWW::Shopify";
 	my $self = bless { _shop_url => $shop_url, _ua => $ua, _url_handler => undef, _api_calls => 0, _sleep_for_limit => 0, _last_timestamp => undef }, $package;
 	$self->url_handler(new WWW::Shopify::URLHandler($self));
-	$self->login_admin($email, $password) if defined $email && defined $password;
 	return $self;
 }
 
@@ -196,7 +195,7 @@ sub use_url {
 	}
 	print STDERR uc($type) . " " . $response->request->uri . "\n" if $ENV{'SHOPIFY_LOG'} && $ENV{'SHOPIFY_LOG'} == 1;
 	print STDERR Dumper($response) if $ENV{'SHOPIFY_LOG'} && $ENV{'SHOPIFY_LOG'} > 1;
-	$self->last_timestamp(DateTime->from_epoch( epoch => str2time($response->header('Date'))) );
+	$self->last_timestamp(DateTime->from_epoch( epoch => str2time($response->header('Date'))) ) if $response && $response->header('Date');
 	return ($decoded, $response);
 }
 
@@ -208,19 +207,23 @@ sub resolve_trailing_url {
 	if ($package->$method && (!$parent || !$parent->is_shop || $package ne "WWW::Shopify::Model::Metafield")) {
 		die new WWW::Shopify::Exception("Cannot get, no parent specified.") unless $parent;
 		if ($package eq "WWW::Shopify::Model::Metafield" && ref($parent) eq 'WWW::Shopify::Model::Product::Image' && $specs) {
-			$specs->{owner_id} = $parent->id;
-			$specs->{owner_resource} = "product_image";
-			return "/admin/" . $package->plural;
+			$specs->{"metafield[owner_id]"} = $parent->id;
+			$specs->{"metafield[owner_resource]"} = "product_image";
+			return "/admin/" . $package->url_plural;
 		}
-		return "/admin/" . $parent->plural . "/" . $parent->id . "/" . $package->plural;
+		# Should be made more generic when I'm sure this won't mess up any other of Shopfy's crazy API.
+		if ($package eq 'WWW::Shopify::Model::Order::Fulfillment::FulfillmentEvent') {
+			return '/admin/' . $parent->associated_parent->url_plural . '/' . $parent->associated_parent->id . '/' . $parent->url_plural . '/' . $parent->id . '/' . $package->url_plural;
+		}
+		return "/admin/" . $parent->url_plural . "/" . $parent->id . "/" . $package->url_plural;
 	}
-	return "/admin/" . $package->plural;
+	return "/admin/" . $package->url_plural;
 }
 
 sub get_all_limit {
 	my ($self, $package, $specs) = @_;
 	$package = $self->translate_model($package);
-	$specs->{"limit"} = PULLING_ITEM_LIMIT unless exists $specs->{"limit"};
+	$specs->{"limit"} = $package->max_per_page unless exists $specs->{"limit"};
 	return () if ($specs->{limit} == 0);
 	return $self->get_shop if $package->is_shop;
 	my $url = $self->resolve_trailing_url($package, "get", $specs->{parent}, $specs) . ".json";
@@ -248,17 +251,24 @@ sub get_all {
 	$package = $self->translate_model($package);
 	$self->validate_item($package);
 	return $self->get_shop if $package->is_shop;
-	return $self->get_all_limit($package, $specs) if ((defined $specs->{"limit"} && $specs->{"limit"} <= PULLING_ITEM_LIMIT) || !$package->countable());
+	
+	my $limit = $specs->{limit};
+	$specs->{limit} = defined $limit && $limit < $package->max_per_page ? $limit : $package->max_per_page;
 	
 	my @return;
+	my $page = $specs->{page};
 	eval {
-		$specs->{page} = 1;
+		$specs->{page} = $specs->{page} ? $specs->{page} : 1;
 		my @chunk;
 		do {
 			@chunk = $self->get_all_limit($package, $specs);
-			push(@return, @chunk);
+			if (!defined $limit || (int(@chunk) + int(@return) < $limit)) {
+				push(@return, @chunk);
+			} else {
+				push(@return, grep { defined $_ } @chunk[0..($limit - int(@return) - 1)]);
+			}
 			$specs->{page}++;
-		} while (int(@chunk) == $specs->{limit});
+		} while (!defined $page && int(@chunk) == $specs->{limit} && (!defined $limit || int(@return) < $limit));
 	};
 	if (my $exception = $@) {
 		$exception->extra(\@return) if ref($exception) && $exception->isa('WWW::Shopify::Exception::CallLimit');
@@ -314,7 +324,36 @@ sub get_count {
 	my ($self, $package, $specs) = @_;
 	$package = $self->translate_model($package);
 	$self->validate_item($package);
-	die "Cannot count $package." unless $package->countable();
+	# If it's not countable (sigh), do a binary search to figure out what the count is. Should find it in ln(n), as opposed to n/250
+	# This is generally better for stores where this could become an issue.
+	if (!$package->countable) {
+		my $limit = $specs->{limit} || $package->max_per_page;
+		my ($lowest_no_items, $highest_items);
+		my $page = 1;
+		my @items;
+		 while (int(@items) == $limit || int(@items) == 0) {
+			@items = $self->get_all_limit($package, { %$specs, limit => $limit, page => $page });
+			return 0 if int(@items) == 0 && $page == 1;
+			if (int(@items) == 0) {
+				$lowest_no_items = $page if !defined $lowest_no_items || $page < $lowest_no_items;
+				# We need to go down.
+				my $differential = int(($highest_items - $page)/2);
+				return ($page-1)*$limit if $differential == 0;
+				$page = $differential + $page;
+			} elsif (int(@items) == $limit) {
+				$highest_items = $page if !defined $highest_items || $page > $highest_items;
+				# We need to go up.
+				if (!defined $lowest_no_items) {
+					$page *= 2;
+				} else {
+					my $differential = int(($lowest_no_items - $page)/2);
+					return $page*$limit if $differential == 0;
+					$page = $differential + $page;
+				}
+			}
+		}
+		return ($page-1)*$limit + int(@items);
+	}
 	my ($decoded, $response) = $self->use_url('get', $self->resolve_trailing_url($package, "get", $specs->{parent}, $specs) . "/count.json", $specs);
 	return $decoded->{'count'};
 }
@@ -466,8 +505,12 @@ sub custom_action {
 	my ($decoded, $response) = $self->use_url('post', $url, {$object->singular() => $object->to_json});
 	return 1 if !$decoded;
 	my $element = $decoded->{$object->singular()};
-	$object = ref($object)->from_json($element, $self);
-	return $object;
+	if ($element) {
+		$object = ref($object)->from_json($element, $self);
+		return $object;
+	} else {
+		return $decoded;
+	}
 }
 
 =head2 activate($self, $charge), disable($self, $discount), enable($self, $discount), open($self, $order), close($self, $order), cancel($self, $order)
@@ -486,61 +529,8 @@ sub approve { return $_[0]->custom_action($_[1], "approve"); }
 sub remove { return $_[0]->custom_action($_[1], "remove"); }
 sub spam { return $_[0]->custom_action($_[1], "spam"); }
 sub not_spam { return $_[0]->custom_action($_[1], "not_spam"); }
+sub account_activation_url { return $_[0]->custom_action($_[1], "account_activation_url"); }
 
-=head2 login_admin($self, $email, $password)
-
-Logs you in to the shop as an admin, allowing you to create and manipulate discount codes, as well as upload files into user-space (not theme space).
-
-Doens't get around the API call limit, unfortunately.
-
-=cut
-
-use HTTP::Request::Common;
-sub login_admin {
-	my ($self, $username, $password) = @_;
-	return 1 if $self->{last_login_check} && (time - $self->{last_login_check}) < 1000;
-	my $ua = $self->ua;
-	die new WWW::Shopify::Exception("Unable to login as admin without a cookie jar.") unless defined $ua->cookie_jar;
-	my $res = $ua->get("https://" . $self->shop_url . "/admin/auth/login");
-	die new WWW::Shopify::Exception("Unable to get login page.") unless $res->is_success;
-	die new WWW::Shopify::Exception("Unable to find authenticity token.") unless $res->decoded_content =~ m/name="authenticity_token".*?value="(\S+)"/ms;
-	my $authenticity_token = $1;
-	my $req = POST "https://" . $self->shop_url . "/admin/auth/login", [
-		login => $username,
-		password => $password,
-		remember => 1,
-		commit => "Sign In",
-		authenticity_token => $authenticity_token
-	];
-	$res = $ua->request($req);
-	die new WWW::Shopify::Exception("Unable to complete request: " . $res->decoded_content) unless $res->is_success || $res->code == 302;
-	die new WWW::Shopify::Exception("Unable to login: $1.") if $res->decoded_content =~ m/class="status system-error">(.*?)<\/div>/;
-	$self->{last_login_check} = time;
-	$self->{authenticity_token} = $authenticity_token;
-	$res = $self->ua->request(GET "https://" . $self->shop_url . "/admin");
-	die new WWW::Shopify::Exception($res) unless $res->decoded_content =~ m/meta name="csrf-token" content="(.*?)"/;
-	$self->{authenticity_token} = $1;
-	$ua->default_header('X-CSRF-Token' => $self->{authenticity_token});
-	return 1;
-}
-
-=head2 logged_in_admin($self)
-
-Determines whether or not you're logged in to the Shopify store as an admin.
-
-=cut
-
-sub logged_in_admin {
-	my ($self) = @_;
-	return undef unless $self->{authenticity_token};
-	return 1 if $self->{last_login_check} && (time - $self->{last_login_check}) < 1000;
-	my $ua = $self->ua;
-	return undef unless $ua->cookie_jar;
-	my $res = $ua->get('https://' . $self->shop_url . '/admin/discounts/count.json');
-	return undef unless $res->is_success;
-	$self->{last_login_check} = time;
-	return 1;
-}
 
 sub is_valid { eval { $_[0]->get_shop; }; return undef if ($@); return 1; }
 sub handleize {
@@ -589,7 +579,7 @@ sub delete_private_app {
 # Internal methods.
 sub validate_item {
 	eval {	die unless $_[1]; $_[1]->is_item; };
-	die new WWW::Shopify::Exception($_[1] . " is not an item!") if ($@);
+	die new WWW::Shopify::Exception($_[1] . " is not an item.") if ($@);
 	die new WWW::Shopify::Exception($_[1] . " requires you to login with an admin account.") if ($_[1]->needs_login && !$_[1]->needs_plus)  && !$_[0]->logged_in_admin;
 }
 
@@ -648,7 +638,7 @@ Follows this: http://wiki.shopify.com/Verifying_Webhooks.
 =cut
 
 use Exporter 'import';
-our @EXPORT_OK = qw(verify_webhook verify_login verify_proxy calc_webhook_signature calc_login_signature calc_proxy_signature handleize);
+our @EXPORT_OK = qw(verify_webhook verify_login verify_proxy calc_webhook_signature calc_login_signature calc_hmac_login_signature calc_proxy_signature handleize);
 use Digest::MD5 'md5_hex';
 use Digest::SHA qw(hmac_sha256_hex hmac_sha256_base64);
 use MIME::Base64;
@@ -668,7 +658,13 @@ sub verify_webhook {
 
 =head2 calc_login_signature($shared_secret, $%params)
 
-Calculates the login signature based on the shared secret and parmaeter hash passed in.
+Calculates the MD5 login signature based on the shared secret and parmaeter hash passed in. This is deprecated.
+
+=cut
+
+=head2 calc_hmac_login_signature($shared_secret, $%params)
+
+Calculates the SHA256 login signature based on the shared secret and parmaeter hash passed in.
 
 =cut
 
@@ -687,10 +683,15 @@ sub calc_login_signature {
 	return md5_hex($shared_secret . join("", map { "$_=" . $params->{$_} } (sort(grep { $_ ne "signature" } keys(%$params)))));
 }
 
+sub calc_hmac_login_signature {
+	my ($shared_secret, $params) = @_;
+	return hmac_sha256_hex(join("&", map { "$_=" . $params->{$_} } (sort(grep { $_ ne "hmac" && $_ ne "signature" } keys(%$params)))), $shared_secret);
+}
+
 sub verify_login {
 	my ($shared_secret, $params) = @_;
-	return undef unless $params->{signature};
-	return calc_login_signature($shared_secret, $params) eq $params->{signature};
+	return undef unless $params->{hmac};
+	return calc_hmac_login_signature($shared_secret, $params) eq $params->{hmac};
 }
 
 =head2 calc_proxy_signature($shared_secret, $%params)
@@ -729,7 +730,7 @@ Adam Harrison (adamdharrison@gmail.com)
 
 =head1 LICENSE
 
-Copyright (C) 2014 Adam Harrison
+Copyright (C) 2016 Adam Harrison
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 
