@@ -132,12 +132,24 @@ sub generate($) {
 sub data_type { return WWW::Shopify::Field::TYPE_QUANTITATIVE; }
 sub validate($$) { return is_float($_[1]); }
 
+package WWW::Shopify::Field::Timestamp;
+use parent 'WWW::Shopify::Field';
+use String::Numeric qw(is_int);
+sub sql_type { return "bigint"; }
+sub generate($) { 
+	return int(rand(10000000)) if (int(@{$_[0]->{arguments}}) == 0);
+	return $_[0]->{arguments}->[0] if (int(@{$_[0]->{arguments}}) == 1);
+	return int(rand($_[0]->{arguments}->[1] - $_[0]->{arguments}->[0] + 1) + $_[0]->{arguments}->[0]);
+}
+sub data_type { return WWW::Shopify::Field::TYPE_QUANTITATIVE; }
+sub validate { return is_int($_[1]); }
+
 package WWW::Shopify::Field::Timezone;
 use parent 'WWW::Shopify::Field';
 sub sql_type { return "varchar(255)"; }
 
 my %from_shopify_timezones = (
-	"(GMT-05:00) Eastern Time (US & Canada)" => "America/New_York" ,
+	"(GMT-05:00) Eastern Time (US & Canada)" => "America/New_York",
 	"(GMT-11:00) International Date Line West" => "-1100",
 	"(GMT-11:00) Midway Island" => "Pacific/Midway",
 	"(GMT-11:00) American Samoa" => "Pacific/Pago_Pago",
@@ -277,10 +289,51 @@ my %from_shopify_timezones = (
 	"(GMT+12:00) Kamchatka" => "Asia/Kamchatka",
 	"(GMT+12:00) Marshall Is." => "Pacific/Majuro",
 	"(GMT+12:00) Auckland" => "Pacific/Auckland",
+	"(GMT+12:00) Pacific/Auckland" => "Pacific/Auckland",
 	"(GMT+12:00) Wellington" => "Pacific/Auckland",
 	"(GMT+13:00) Nuku'alofa" => "Pacific/Tongatapu",
 	"(GMT+13:00) Tokelau Is." => "Pacific/Fakaofo",
-	"(GMT+13:00) Samoa" => "Pacific/Apia"
+	"(GMT+13:00) Samoa" => "Pacific/Apia",
+	
+	"(GMT-10:00) Pacific/Honolulu" => "Pacific/Honolulu",
+	"(GMT-08:00) America/Los_Angeles" => "America/Los_Angeles",
+	"(GMT-08:00) America/Vancouver" => "America/Vancouver",
+	"(GMT-07:00) America/Denver" => "America/Denver",
+	"(GMT-07:00) America/Phoenix" => "America/Phoenix",
+	"(GMT-06:00) America/Chicago" => "America/Chicago",
+	"(GMT-05:00) America/New_York" => "America/New_York",
+	"(GMT-05:00) America/Toronto" => "America/Toronto",
+	"(GMT-05:00) America/Montreal" => "America/Montreal",
+	"(GMT-03:00) America/Montevideo" => "America/Montevideo",
+	"(GMT+00:00) Europe/London" => "Europe/London",
+	"(GMT+01:00) Europe/Madrid" => "Europe/Madrid",
+	"(GMT+01:00) Europe/Oslo" => "Europe/Oslo",
+	"(GMT+01:00) Europe/Stockholm" => "Europe/Stockholm",
+	"(GMT+05:00) Asia/Karachi" => "Asia/Karachi",
+	"(GMT+05:30) Asia/Calcutta" => "Asia/Calcutta",
+	"(GMT+09:30) Australia/South" => "Australia/South",
+	"(GMT+10:00) Australia/NSW" => "Australia/NSW",
+	"(GMT+10:00) Australia/Queensland" => "Australia/Queensland",
+	"(GMT+10:00) Australia/Victoria" => "Australia/Victoria",
+	
+	"(GMT-03:00) Montevideo" => "America/Montevideo",
+	"(GMT+02:00) Kaliningrad" => "Europe/Kaliningrad",
+	"(GMT+03:00) Moscow" => "Europe/Moscow",
+	"(GMT+03:00) St. Petersburg" => "Europe/Moscow",
+	"(GMT+03:00) Volgograd" => "Europe/Volgograd",
+	"(GMT+04:00) Samara" => "Europe/Samara",
+	"(GMT+05:00) Ekaterinburg" => "Asia/Yekaterinburg",
+	"(GMT+06:00) Novosibirsk" => "Asia/Novosibirsk",
+	"(GMT+06:00) Urumqi" => "Asia/Urumqi",
+	"(GMT+07:00) Krasnoyarsk" => "Asia/Krasnoyarsk",
+	"(GMT+08:00) Irkutsk" => "Asia/Irkutsk",
+	"(GMT+08:00) Ulaanbaatar" => "Asia/Ulaanbaatar",
+	"(GMT+09:00) Yakutsk" => "Asia/Yakutsk",
+	"(GMT+10:00) Magadan" => "Asia/Magadan",
+	"(GMT+10:00) Vladivostok" => "Asia/Vladivostok",
+	"(GMT+11:00) Solomon Is." => "Pacific/Guadalcanal",
+	"(GMT+11:00) Srednekolymsk" => "Asia/Srednekolymsk",
+	"(GMT+12:45) Chatham Is." => "Pacific/Chatham"
 );
 my %to_shopify_timezones = reverse(%from_shopify_timezones);
 
@@ -308,6 +361,28 @@ sub generate {
 	return $timezones[int(rand(@timezones))];
 }
 
+package WWW::Shopify::Field::Timezone::IANA;
+use parent 'WWW::Shopify::Field';
+
+sub sql_type { return "varchar(255)"; }
+sub to_shopify {
+	my $dttz = $_[1];
+	return undef unless $dttz;
+	return $dttz->name;
+}
+
+sub from_shopify {
+	my $dttz = $_[1];
+	return undef unless $dttz;
+	return DateTime::TimeZone->new(name => $dttz);
+}
+
+sub generate {
+	my @timezones = values(%WWW::Shopify::Field::Timezone::from_shopify_timezones);
+	return $timezones[int(rand(@timezones))];
+}
+
+
 
 package WWW::Shopify::Field::Currency;
 use parent 'WWW::Shopify::Field';
@@ -337,12 +412,14 @@ sub to_shopify {
 		$t =~ s/(\d\d)$/:$1/;
 		return $t;
 	}
-	die new WWW::Shopify::Exception($dt) unless $dt =~ m/([\d-]+)\s*T?\s*([\d:]+)/;
+	die new WWW::Shopify::Exception($_[0]->name . ": " . $dt) unless $dt =~ m/([\d-]+)\s*T?\s*([\d:]+)/;
 	return "$1T$2";
 }
 sub from_shopify {
 	my $dt; 
 	return undef unless $_[1];
+	my @abbrvs = qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec);
+	my $abbrvs_reg = join("|", @abbrvs);
 	if ($_[1] =~ m/(\d+)-(\d+)-(\d+)T(\d+):(\d+):(\d+)([+-]\d+):(\d+)/) {
 		$dt = DateTime->new(
 			year      => $1,
@@ -364,8 +441,20 @@ sub from_shopify {
 			second    => $6,
 		);
 	}
+	elsif ($_[1] =~ m/(\d+):(\d+):(\d+) ($abbrvs_reg) (\d+), (\d+)/) {
+		my %types = map { $abbrvs[$_] => ($_+1) } 0..$#abbrvs;
+		$dt = DateTime->new(
+			hour      => $1,
+			minute    => $2,
+			second    => $3,
+			
+			year      => $6,
+			month     => $types{$4},
+			day       => $5,
+		);
+	}
 	else {
-		die new WWW::Shopify::Exception("Unable to parse date " . $_[1]) unless $_[1] =~ m/(\d+)-(\d+)-(\d+)/;
+		die new WWW::Shopify::Exception("Unable to parse date " . $_[0]->name . " " . $_[1]) unless $_[1] =~ m/(\d+)-(\d+)-(\d+)/;
 		$dt = DateTime->new(
 			year      => $1,
 			month     => $2,
@@ -377,10 +466,11 @@ sub from_shopify {
 sub validate($) { return scalar($_[1] =~ m/(\d+-\d+-\d+)T?(\d+:\d+:\d+)/); }
 
 sub generate($) {
-	my %hash = @{$_[0]->{arguments}};
+	my %hash = $_[1] ? %{$_[1]} : @{$_[0]->{arguments}};
 	$hash{min} = '2010-01-01 00:00:00' unless $hash{min};
 	$hash{max} = 'now' unless $hash{max};
-	return ::rand_datetime(%hash);
+	my $date = ::rand_datetime(%hash);
+	return $date;
 }
 sub data_type { return WWW::Shopify::Field::TYPE_QUANTITATIVE; }
 
@@ -403,4 +493,13 @@ sub validate { return !defined $_[1] || (ref($_[1]) && ref($_[1]) eq "ARRAY"); }
 sub to_shopify { return $_[1]; }
 sub from_shopify { return $_[1]; }
 
+package WWW::Shopify::Field::Freeform::Hash;
+use parent 'WWW::Shopify::Field';
+sub sql_type { return "text"; }
+sub generate { return {}; }
+sub data_type { return WWW::Shopify::Field::TYPE_QUALITATIVE; }
+sub validate { return !defined $_[1] || (ref($_[1]) && ref($_[1]) eq "HASH"); }
+sub to_shopify { return $_[1]; }
+sub from_shopify { return $_[1]; }
+
 1;
