@@ -42,6 +42,10 @@ sub parent { return "WWW::Shopify::Model::Blog" }
 sub creation_minimal { return qw(title); }
 sub update_fields { return qw(author body_html summary_html published_at tags title); }
 sub included_in_parnet { return 0; }
+sub get_through_parent { return undef; }
+sub update_through_parent { return undef; } 
+sub delete_through_parent { return undef; }
+
 
 sub read_scope { return "read_content"; }
 sub write_scope { return "write_content"; }
