@@ -16,12 +16,13 @@ my $fields; sub fields { return $fields; }
 BEGIN { $fields = {
 	"key" => new WWW::Shopify::Field::Identifier::String(),
 	"value" => new WWW::Shopify::Field::Text::HTML(),
+	"theme_id" => new WWW::Shopify::Field::Relation::Parent("WWW::Shopify::Model::Theme"),
 	"attachment" => new WWW::Shopify::Field::Text(),
 	"public_url" => new WWW::Shopify::Field::String::URL(),
 	"source_key" => new WWW::Shopify::Field::String(),
 	"src" => new WWW::Shopify::Field::String::URL(),
-	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
-	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
+	"created_at" => new WWW::Shopify::Field::Date(),
+	"updated_at" => new WWW::Shopify::Field::Date(),
 	"content_type" => new WWW::Shopify::Field::String("image/(gif|jpg|png)"),
 	"size" => new WWW::Shopify::Field::Int(1, 5000)
 }; }
