@@ -16,8 +16,8 @@ BEGIN { $fields = {
 	"tags" => new WWW::Shopify::Field::String(),
 	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield"),
 	"id" => new WWW::Shopify::Field::Identifier(),
-	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
-	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
+	"created_at" => new WWW::Shopify::Field::Date(),
+	"updated_at" => new WWW::Shopify::Field::Date(),
 	"feedburner" => new WWW::Shopify::Field::String(),
 	"feedburner_location" => new WWW::Shopify::Field::String(),
 	"template_suffix" => new WWW::Shopify::Field::String()
