@@ -11,14 +11,16 @@ use parent "WWW::Shopify::Model::Item";
 my $fields; sub fields { return $fields; } 
 BEGIN { $fields = {
 	# Not described in detail enough.
-	#"carrier_shipping_rate_proiders" => new WWW::Shopify::Field::Relation::Many()
-	#"price_based_Shipping_rates" => new WWW::Shopify::Field::Relation::Many()
-	# "weight_based_shipping_rates" => new WWW::Shopify::Field::Relation::Many()
+	"carrier_shipping_rate_proiders" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::ShippingZone::CarrierServiceShippingRateProvider"),
+	"price_based_shipping_rates" =>  new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::ShippingZone::PriceBasedShippingRate"),
+	"weight_based_shipping_rates" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::ShippingZone::WeightBasedShippingRate"),
 	"code" => new WWW::Shopify::Field::String::CountryCode(),
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"name" => new WWW::Shopify::Field::String::Country(),
 	"provinces" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Country::Province"),
-	"tax" => new WWW::Shopify::Field::Float()
+	"tax" => new WWW::Shopify::Field::Float(),
+	"tax_name" => new WWW::Shopify::Field::String(),
+	"shipping_zone_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::ShippingZone")
 	
 }; }
 my $queries; sub queries { return $queries; }
