@@ -22,7 +22,7 @@ BEGIN { $fields = {
 	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield"),
 	"image" => new WWW::Shopify::Field::Relation::OwnOne('WWW::Shopify::Model::CustomCollection::Image'),
 	"title" => new WWW::Shopify::Field::String::Words(1, 2),
-	"collects" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::CustomCollection::Collect")
+	"collects" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::CustomCollection::Collect", { direct => 1, key => "collection_id" })
 }; }
 my $queries; sub queries { return $queries; }
 BEGIN { $queries = {
