@@ -69,7 +69,7 @@ sub searchable($) { return 1; }
 sub read_scope { return "read_customers"; }
 sub write_scope { return "write_customers"; }
 
-sub actions { return qw(enable disable); }
+sub actions { return qw(enable disable account_activation_url); }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
