@@ -33,6 +33,9 @@ sub actions { return qw(disable enable); }
 
 sub countable { return 0; }
 
+sub default_per_page { return 15; }
+sub max_per_page { return 200; }
+
 sub needs_login { return 1; }
 sub needs_plus { return 1; }
 
