@@ -21,7 +21,7 @@ BEGIN { $fields = {
 	"verb" => new WWW::Shopify::Field::String()
 }; }
 
-sub get_all_through_parent { return 1; }
+sub get_all_through_parent { return undef; }
 sub get_through_parent { return undef; }
 sub creatable { return undef; }
 sub updatable { return undef; }
