@@ -113,6 +113,10 @@ Returns the text representing the plural form of this package. (WWW::Shopify::Mo
 
 sub plural { return $_[0]->singular() . "s"; }
 
+# Sigh. Yet again let's just violate conventions on a single resource, necessitating yet more methods.
+# I'm looking at you, fulfillment event.
+sub url_singular { return $_[0]->singular; }
+sub url_plural { return $_[0]->plural; }
 
 sub needs_login { return undef; }
 sub needs_form_encoding_get_all { return undef; }
@@ -178,6 +182,7 @@ sub can_enable { return $_[0]->can_action("enable"); }
 sub can_disable { return $_[0]->can_action("disable"); }
 sub can_close { return $_[0]->can_action("close"); }
 sub can_cancel { return $_[0]->can_action("cancel"); }
+sub can_account_activation_url { return $_[0]->can_action("account_activation_url"); }
 
 =head2 create_method($package), update_method($package), delete_method($package)
 
@@ -295,6 +300,23 @@ sub close_through_parent { return defined $_[0]->parent; }
 sub cancel_through_parent { return defined $_[0]->parent; }
 sub enable_through_parent { return defined $_[0]->parent; }
 sub disable_through_parent { return defined $_[0]->parent; }
+sub account_activation_url_through_parent { return defined $_[0]->parent; }
+
+=head2 max_per_page
+
+Tells you how many you can grab in a single page.
+
+=cut
+
+sub max_per_page { return 250; }
+
+=head2 default_per_page
+
+Tells you how many entries you'll get by default.
+
+=cut
+
+sub default_per_page { return 50; }
 
 =head2 included_in_parent
 
@@ -402,7 +424,9 @@ sub from_json {
 				if ($ref->{$_}->is_many()) {
 					# This may not be necesasry, but this is such fundamental code I don't want to mess with it.
 					next unless exists $json->{$package->plural()} || exists $json->{$_};
-					my @objects = exists $json->{$package->plural()} ? @{$json->{$package->plural()}} : @{$json->{$_}};
+					my @objects;
+					my $index = exists $json->{$package->plural()} ? $package->plural : $_;
+					@objects = defined $json->{$index} ? @{$json->{$index}} : ();
 					$self->{$_} = [map {
 						my $o = $package->from_json($_, $associated);
 						$o->associated_parent($self);
@@ -483,6 +507,12 @@ sub to_json($) {
 	return $final;
 }
 
+# Quick n' dirty clone method.
+sub clone {
+	my ($self) = @_;
+	return ref($self)->from_json($self->to_json);
+}
+
 sub generate_accessors {
 	return join("\n", 
 		(map { "__PACKAGE__->queries->{$_}->name('$_');" } keys(%{$_[0]->queries})),
