@@ -73,6 +73,8 @@ BEGIN { $fields = {
 	"refunds" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Refund"),
 	"risks" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Order::Risk"),
 	
+	"payment_gateway_names" => new WWW::Shopify::Field::Freeform::Array(),
+	
 	"send_webhooks" => new WWW::Shopify::Field::Boolean(),
 	"send_receipt" => new WWW::Shopify::Field::Boolean(),
 	"send_fulfillment_receipt" => new WWW::Shopify::Field::Boolean(),
@@ -102,7 +104,7 @@ sub actions { return qw(open close cancel); }
 sub get_fields { return grep { $_ ne "send_webhooks" && $_ ne "send_receipt" && $_ ne "send_fulfillment_receipt" && $_ ne "inventory_behaviour" } keys(%$fields); }
 sub creation_minimal { return qw(line_items); }
 sub update_filled { return qw(updated_at); }
-sub update_fields { return qw(note note_attributes email buyer_accepts_marketing customer tags); };
+sub update_fields { return qw(note note_attributes email buyer_accepts_marketing customer tags name); };
 
 sub status {
 	return "cancelled" if $_[0]->cancelled_at;
