@@ -17,6 +17,10 @@ sub fields {
 	$fields->{properties}->name('properties');
 	$fields->{tax_lines} = new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Order::Fulfillment::LineItem::TaxLine");
 	$fields->{tax_lines}->name('tax_lines');
+	$fields->{origin_location} = new WWW::Shopify::Field::Relation::OwnOne("WWW::Shopify::Model::Order::Fulfillment::LineItem::Location");
+	$fields->{origin_location}->name('origin_location');
+	$fields->{destination_location} = new WWW::Shopify::Field::Relation::OwnOne("WWW::Shopify::Model::Order::Fulfillment::LineItem::Location");
+	$fields->{destination_location}->name('destination_location');
 	return $fields;
 }
 
