@@ -33,6 +33,8 @@ BEGIN { $fields = {
 	"name" => new WWW::Shopify::Field::String::Words(1, 3),
 	"properties" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Order::LineItem::Property"),
 	"tax_lines" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Order::LineItem::TaxLine"),
+	"origin_location" => new WWW::Shopify::Field::Relation::OwnOne("WWW::Shopify::Model::Order::LineItem::Location"),
+	"destination_location" => new WWW::Shopify::Field::Relation::OwnOne("WWW::Shopify::Model::Order::LineItem::Location"),
 	"taxable" => new WWW::Shopify::Field::Boolean(),
 	"variant_inventory_management" => new WWW::Shopify::Field::String::Enum(["shopify", "manual"]) };
 }
