@@ -28,6 +28,7 @@ BEGIN { $fields = {
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"created_at" => new WWW::Shopify::Field::Date(),
 	"published_at" => new WWW::Shopify::Field::Date(),
+	"published" => new WWW::Shopify::Field::Boolean(),
 	"updated_at" => new WWW::Shopify::Field::Date()};
 }
 my $queries; sub queries { return $queries; }
@@ -52,12 +53,12 @@ BEGIN { $queries = {
 }; }
 
 
-sub get_fields { return grep { $_ ne "collects" } keys(%$fields); }
+sub get_fields { return grep { $_ ne "collects" && $_ ne "published" } keys(%$fields); }
 sub creation_minimal { return qw(title product_type vendor); }
 sub creation_filled { return qw(id created_at); }
 # Odd, even without an update method, it still has an updated at.
 sub update_filled { return qw(updated_at); }
-sub update_fields { return qw(metafields handle product_type title template_suffix vendor tags images options body_html variants published_at); }
+sub update_fields { return qw(metafields handle product_type title template_suffix vendor tags images options body_html variants published_at published); }
 sub throws_webhooks { return 1; }
 
 sub read_scope { return "read_products"; }
