@@ -22,7 +22,7 @@ BEGIN { $fields = {
 	"variant_ids" => new WWW::Shopify::Field::Freeform::Array()
 }; }
 
-sub creation_minimal { return qw(filename); }
+#sub creation_minimal { return qw(filename); }
 sub creation_filled { return qw(id created_at ); }
 sub update_filled { return qw(updated_at); } 
 sub update_fields { return qw(metafields position variant_ids); }
