@@ -15,11 +15,13 @@ BEGIN { $fields = {
 	"note" => new WWW::Shopify::Field::String(),
 	"refund_line_items" => new WWW::Shopify::Field::Relation::Many('WWW::Shopify::Model::Refund::LineItem'),
 	"restock" => new WWW::Shopify::Field::Boolean(),
-	"transactions" => new WWW::Shopify::Field::Relation::Many('WWW::Shopify::Model::Transaction'),
+	"transactions" => new WWW::Shopify::Field::Relation::Many('WWW::Shopify::Model::Refund::Transaction'),
 	"user_id" => new WWW::Shopify::Field::Relation::ReferenceOne('WWW::Shopify::Model::User')
 }; }
 
 sub parent { return 'WWW::Shopify::Model::Order'; }
+sub gettable { return undef; }
+sub singlable { return 1; }
 sub creatable { return undef; }
 sub countable { return undef; }
 sub updatable { return undef; }
