@@ -85,6 +85,11 @@ BEGIN { $fields = {
 	"receipt_email" => new WWW::Shopify::Field::Freeform(),
 	"receipt_number" => new WWW::Shopify::Field::Freeform(),
 	"shipping" => new WWW::Shopify::Field::Freeform(),
+	"source" => new WWW::Shopify::Field::Freeform(),
+	# Gift Card
+	"gift_card_id" => new WWW::Shopify::Field::String(),
+	"gift_card_masked_code" => new WWW::Shopify::Field::String(),
+	"gift_card_last_characters" => new WWW::Shopify::Field::String()
 }; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
