@@ -24,7 +24,8 @@ BEGIN { $fields = {
 	"user_type" => new WWW::Shopify::Field::String::Enum(["regular", "open_id", "restricted"])
 }; }
 
-sub requires_plus { return 1; }
+sub needs_plus { return 1; }
+sub countable { return undef; }
 sub creatable { return undef; }
 sub deletable { return undef; }
 sub updatable { return undef; }
