@@ -62,6 +62,21 @@ use URI::Escape;
 use JSON qw(encode_json);
 use Scalar::Util qw(reftype);
 
+
+sub flatten_object {
+	my ($prefix, $object) = @_;
+	return map {  
+		my $key = $_;
+		my @items;
+		@items = $object->{$key}->iso8601 if (ref($object) || "") eq "DateTime";
+		@items = flatten_object($prefix . $key, $object->{$key}) if reftype($object->{$key}) && reftype($object->{$key}) eq "HASH";
+		@items = (map { flatten_object($prefix . "[" . $key . "][]", $_) } @{$object->{$key}}) if reftype($object->{$key}) && reftype($object->{$key}) eq "ARRAY";
+		@items = ($prefix . "[" . $key . "]=" . uri_escape_utf8(defined $object->{$key} ? $object->{$key} : '')) if !reftype($object->{$key});
+		
+		@items;
+	} grep { $_ ne "associated_parent" && $_ ne "associated_sa" } keys(%$object);
+}
+
 sub use_url{
 	my ($self, $method, $url, $hash, $needs_login, $type, $accept) = @_;
 	$type = "application/json" unless $type;
@@ -72,19 +87,6 @@ sub use_url{
 		$request->content($hash ? encode_json($hash) : undef);
 	} else {
 		if ($hash) {
-			sub flatten_object {
-				my ($prefix, $object) = @_;
-				return map {  
-					my $key = $_;
-					my @items;
-					@items = flatten_object($prefix . $key, $object->{$key}) if reftype($object->{$key}) && reftype($object->{$key}) eq "HASH";
-					@items = (map { flatten_object($prefix . "[" . $key . "][]", $_) } @{$object->{$key}}) if reftype($object->{$key}) && reftype($object->{$key}) eq "ARRAY";
-					@items = ($prefix . "[" . $key . "]=" . uri_escape_utf8(defined $object->{$key} ? $object->{$key} : '')) if !reftype($object->{$key});
-					
-					
-					@items;
-				} keys(%$object);
-			}
 			$request->content(join("&", map { 
 				if (reftype($hash->{$_}) && reftype($hash->{$_}) eq "HASH") {
 					flatten_object($_, $hash->{$_});
@@ -117,6 +119,7 @@ sub use_url{
 		if ($response->is_redirect) {
 			
 		}
+		return (undef, $response);
 	}
 }
 sub put_url { return shift->use_url("PUT", @_); }
